# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EventPage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"layout": "Layout", "can_edit": "bool", "title": "str"}

    attribute_map = {"layout": "layout", "can_edit": "canEdit", "title": "title"}

    def __init__(self, layout=None, can_edit=None, title=None):  # noqa: E501
        """EventPage - a model defined in Swagger"""  # noqa: E501
        self._layout = None
        self._can_edit = None
        self._title = None
        self.discriminator = None
        self.layout = layout
        self.can_edit = can_edit
        self.title = title

    @property
    def layout(self):
        """Gets the layout of this EventPage.  # noqa: E501


        :return: The layout of this EventPage.  # noqa: E501
        :rtype: Layout
        """
        return self._layout

    @layout.setter
    def layout(self, layout):
        """Sets the layout of this EventPage.


        :param layout: The layout of this EventPage.  # noqa: E501
        :type: Layout
        """
        if layout is None:
            raise ValueError(
                "Invalid value for `layout`, must not be `None`"
            )  # noqa: E501

        self._layout = layout

    @property
    def can_edit(self):
        """Gets the can_edit of this EventPage.  # noqa: E501

        Whether the user doing the request can edit the event  # noqa: E501

        :return: The can_edit of this EventPage.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit

    @can_edit.setter
    def can_edit(self, can_edit):
        """Sets the can_edit of this EventPage.

        Whether the user doing the request can edit the event  # noqa: E501

        :param can_edit: The can_edit of this EventPage.  # noqa: E501
        :type: bool
        """
        if can_edit is None:
            raise ValueError(
                "Invalid value for `can_edit`, must not be `None`"
            )  # noqa: E501

        self._can_edit = can_edit

    @property
    def title(self):
        """Gets the title of this EventPage.  # noqa: E501

        The event's title translated to the requested lang  # noqa: E501

        :return: The title of this EventPage.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this EventPage.

        The event's title translated to the requested lang  # noqa: E501

        :param title: The title of this EventPage.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError(
                "Invalid value for `title`, must not be `None`"
            )  # noqa: E501

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(EventPage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockPagePreview(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "page_id": "str",
        "slug": "str",
        "published_at": "datetime",
        "author": "BlockUser",
        "title": "str",
        "excerpt": "str",
        "image": "BlockImage",
        "variant": "str",
        "site": "SiteReference",
        "tags": "BlockTagReferenceList",
        "metadata": "list[MetadataReference]",
        "reactions": "BlockReactions",
        "order": "list[str]",
        "external_url": "str",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "page_id": "pageId",
        "slug": "slug",
        "published_at": "publishedAt",
        "author": "author",
        "title": "title",
        "excerpt": "excerpt",
        "image": "image",
        "variant": "variant",
        "site": "site",
        "tags": "tags",
        "metadata": "metadata",
        "reactions": "reactions",
        "order": "order",
        "external_url": "externalUrl",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        page_id=None,
        slug=None,
        published_at=None,
        author=None,
        title=None,
        excerpt=None,
        image=None,
        variant=None,
        site=None,
        tags=None,
        metadata=None,
        reactions=None,
        order=None,
        external_url=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockPagePreview - a model defined in Swagger"""  # noqa: E501
        self._page_id = None
        self._slug = None
        self._published_at = None
        self._author = None
        self._title = None
        self._excerpt = None
        self._image = None
        self._variant = None
        self._site = None
        self._tags = None
        self._metadata = None
        self._reactions = None
        self._order = None
        self._external_url = None
        self.discriminator = None
        self.page_id = page_id
        self.slug = slug
        if published_at is not None:
            self.published_at = published_at
        if author is not None:
            self.author = author
        if title is not None:
            self.title = title
        if excerpt is not None:
            self.excerpt = excerpt
        if image is not None:
            self.image = image
        self.variant = variant
        self.site = site
        if tags is not None:
            self.tags = tags
        if metadata is not None:
            self.metadata = metadata
        if reactions is not None:
            self.reactions = reactions
        self.order = order
        if external_url is not None:
            self.external_url = external_url
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def page_id(self):
        """Gets the page_id of this BlockPagePreview.  # noqa: E501

        The page's id.  # noqa: E501

        :return: The page_id of this BlockPagePreview.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this BlockPagePreview.

        The page's id.  # noqa: E501

        :param page_id: The page_id of this BlockPagePreview.  # noqa: E501
        :type: str
        """
        if page_id is None:
            raise ValueError(
                "Invalid value for `page_id`, must not be `None`"
            )  # noqa: E501

        self._page_id = page_id

    @property
    def slug(self):
        """Gets the slug of this BlockPagePreview.  # noqa: E501

        The page's slug, used for navigation purposes.  # noqa: E501

        :return: The slug of this BlockPagePreview.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this BlockPagePreview.

        The page's slug, used for navigation purposes.  # noqa: E501

        :param slug: The slug of this BlockPagePreview.  # noqa: E501
        :type: str
        """
        if slug is None:
            raise ValueError(
                "Invalid value for `slug`, must not be `None`"
            )  # noqa: E501

        self._slug = slug

    @property
    def published_at(self):
        """Gets the published_at of this BlockPagePreview.  # noqa: E501

        The date and time when the page was published.  # noqa: E501

        :return: The published_at of this BlockPagePreview.  # noqa: E501
        :rtype: datetime
        """
        return self._published_at

    @published_at.setter
    def published_at(self, published_at):
        """Sets the published_at of this BlockPagePreview.

        The date and time when the page was published.  # noqa: E501

        :param published_at: The published_at of this BlockPagePreview.  # noqa: E501
        :type: datetime
        """

        self._published_at = published_at

    @property
    def author(self):
        """Gets the author of this BlockPagePreview.  # noqa: E501


        :return: The author of this BlockPagePreview.  # noqa: E501
        :rtype: BlockUser
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this BlockPagePreview.


        :param author: The author of this BlockPagePreview.  # noqa: E501
        :type: BlockUser
        """

        self._author = author

    @property
    def title(self):
        """Gets the title of this BlockPagePreview.  # noqa: E501

        The page's title.  # noqa: E501

        :return: The title of this BlockPagePreview.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BlockPagePreview.

        The page's title.  # noqa: E501

        :param title: The title of this BlockPagePreview.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def excerpt(self):
        """Gets the excerpt of this BlockPagePreview.  # noqa: E501

        A short extract of the page's content.  # noqa: E501

        :return: The excerpt of this BlockPagePreview.  # noqa: E501
        :rtype: str
        """
        return self._excerpt

    @excerpt.setter
    def excerpt(self, excerpt):
        """Sets the excerpt of this BlockPagePreview.

        A short extract of the page's content.  # noqa: E501

        :param excerpt: The excerpt of this BlockPagePreview.  # noqa: E501
        :type: str
        """

        self._excerpt = excerpt

    @property
    def image(self):
        """Gets the image of this BlockPagePreview.  # noqa: E501


        :return: The image of this BlockPagePreview.  # noqa: E501
        :rtype: BlockImage
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this BlockPagePreview.


        :param image: The image of this BlockPagePreview.  # noqa: E501
        :type: BlockImage
        """

        self._image = image

    @property
    def variant(self):
        """Gets the variant of this BlockPagePreview.  # noqa: E501


        :return: The variant of this BlockPagePreview.  # noqa: E501
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this BlockPagePreview.


        :param variant: The variant of this BlockPagePreview.  # noqa: E501
        :type: str
        """
        if variant is None:
            raise ValueError(
                "Invalid value for `variant`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["VERTICAL", "HORIZONTAL", "COVER", "SIDE"]  # noqa: E501
        if variant not in allowed_values:
            raise ValueError(
                "Invalid value for `variant` ({0}), must be one of {1}".format(  # noqa: E501
                    variant, allowed_values
                )
            )

        self._variant = variant

    @property
    def site(self):
        """Gets the site of this BlockPagePreview.  # noqa: E501


        :return: The site of this BlockPagePreview.  # noqa: E501
        :rtype: SiteReference
        """
        return self._site

    @site.setter
    def site(self, site):
        """Sets the site of this BlockPagePreview.


        :param site: The site of this BlockPagePreview.  # noqa: E501
        :type: SiteReference
        """
        if site is None:
            raise ValueError(
                "Invalid value for `site`, must not be `None`"
            )  # noqa: E501

        self._site = site

    @property
    def tags(self):
        """Gets the tags of this BlockPagePreview.  # noqa: E501


        :return: The tags of this BlockPagePreview.  # noqa: E501
        :rtype: BlockTagReferenceList
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this BlockPagePreview.


        :param tags: The tags of this BlockPagePreview.  # noqa: E501
        :type: BlockTagReferenceList
        """

        self._tags = tags

    @property
    def metadata(self):
        """Gets the metadata of this BlockPagePreview.  # noqa: E501


        :return: The metadata of this BlockPagePreview.  # noqa: E501
        :rtype: list[MetadataReference]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this BlockPagePreview.


        :param metadata: The metadata of this BlockPagePreview.  # noqa: E501
        :type: list[MetadataReference]
        """

        self._metadata = metadata

    @property
    def reactions(self):
        """Gets the reactions of this BlockPagePreview.  # noqa: E501


        :return: The reactions of this BlockPagePreview.  # noqa: E501
        :rtype: BlockReactions
        """
        return self._reactions

    @reactions.setter
    def reactions(self, reactions):
        """Sets the reactions of this BlockPagePreview.


        :param reactions: The reactions of this BlockPagePreview.  # noqa: E501
        :type: BlockReactions
        """

        self._reactions = reactions

    @property
    def order(self):
        """Gets the order of this BlockPagePreview.  # noqa: E501

        The display order of the properties.  # noqa: E501

        :return: The order of this BlockPagePreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this BlockPagePreview.

        The display order of the properties.  # noqa: E501

        :param order: The order of this BlockPagePreview.  # noqa: E501
        :type: list[str]
        """
        if order is None:
            raise ValueError(
                "Invalid value for `order`, must not be `None`"
            )  # noqa: E501

        self._order = order

    @property
    def external_url(self):
        """Gets the external_url of this BlockPagePreview.  # noqa: E501

        The URL to an external resource.  # noqa: E501

        :return: The external_url of this BlockPagePreview.  # noqa: E501
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """Sets the external_url of this BlockPagePreview.

        The URL to an external resource.  # noqa: E501

        :param external_url: The external_url of this BlockPagePreview.  # noqa: E501
        :type: str
        """

        self._external_url = external_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockPagePreview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockPagePreview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Header(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "label": "str",
        "label_key": "str",
        "icon": "str",
        "style": "ElementStyle",
    }

    attribute_map = {
        "label": "label",
        "label_key": "labelKey",
        "icon": "icon",
        "style": "style",
    }

    def __init__(self, label=None, label_key=None, icon=None, style=None):  # noqa: E501
        """Header - a model defined in Swagger"""  # noqa: E501
        self._label = None
        self._label_key = None
        self._icon = None
        self._style = None
        self.discriminator = None
        if label is not None:
            self.label = label
        if label_key is not None:
            self.label_key = label_key
        if icon is not None:
            self.icon = icon
        if style is not None:
            self.style = style

    @property
    def label(self):
        """Gets the label of this Header.  # noqa: E501

        The header's text.  # noqa: E501

        :return: The label of this Header.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this Header.

        The header's text.  # noqa: E501

        :param label: The label of this Header.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def label_key(self):
        """Gets the label_key of this Header.  # noqa: E501

        The translation key to use for this header. Note:   If present, this takes precedence over any value present in the label field.   # noqa: E501

        :return: The label_key of this Header.  # noqa: E501
        :rtype: str
        """
        return self._label_key

    @label_key.setter
    def label_key(self, label_key):
        """Sets the label_key of this Header.

        The translation key to use for this header. Note:   If present, this takes precedence over any value present in the label field.   # noqa: E501

        :param label_key: The label_key of this Header.  # noqa: E501
        :type: str
        """

        self._label_key = label_key

    @property
    def icon(self):
        """Gets the icon of this Header.  # noqa: E501

        The header's icon.  # noqa: E501

        :return: The icon of this Header.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this Header.

        The header's icon.  # noqa: E501

        :param icon: The icon of this Header.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def style(self):
        """Gets the style of this Header.  # noqa: E501


        :return: The style of this Header.  # noqa: E501
        :rtype: ElementStyle
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this Header.


        :param style: The style of this Header.  # noqa: E501
        :type: ElementStyle
        """

        self._style = style

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Header, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Header):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockRemote(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "extension_id": "str",
        "extension_properties": "object",
        "global_properties": "object",
        "bundle_url": "str",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "extension_id": "extensionId",
        "extension_properties": "extensionProperties",
        "global_properties": "globalProperties",
        "bundle_url": "bundleUrl",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        extension_id=None,
        extension_properties=None,
        global_properties=None,
        bundle_url=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockRemote - a model defined in Swagger"""  # noqa: E501
        self._extension_id = None
        self._extension_properties = None
        self._global_properties = None
        self._bundle_url = None
        self.discriminator = None
        self.extension_id = extension_id
        self.extension_properties = extension_properties
        if global_properties is not None:
            self.global_properties = global_properties
        if bundle_url is not None:
            self.bundle_url = bundle_url
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def extension_id(self):
        """Gets the extension_id of this BlockRemote.  # noqa: E501

        The extension's id.  # noqa: E501

        :return: The extension_id of this BlockRemote.  # noqa: E501
        :rtype: str
        """
        return self._extension_id

    @extension_id.setter
    def extension_id(self, extension_id):
        """Sets the extension_id of this BlockRemote.

        The extension's id.  # noqa: E501

        :param extension_id: The extension_id of this BlockRemote.  # noqa: E501
        :type: str
        """
        if extension_id is None:
            raise ValueError(
                "Invalid value for `extension_id`, must not be `None`"
            )  # noqa: E501

        self._extension_id = extension_id

    @property
    def extension_properties(self):
        """Gets the extension_properties of this BlockRemote.  # noqa: E501

        The properties configured for this extension.  # noqa: E501

        :return: The extension_properties of this BlockRemote.  # noqa: E501
        :rtype: object
        """
        return self._extension_properties

    @extension_properties.setter
    def extension_properties(self, extension_properties):
        """Sets the extension_properties of this BlockRemote.

        The properties configured for this extension.  # noqa: E501

        :param extension_properties: The extension_properties of this BlockRemote.  # noqa: E501
        :type: object
        """
        if extension_properties is None:
            raise ValueError(
                "Invalid value for `extension_properties`, must not be `None`"
            )  # noqa: E501

        self._extension_properties = extension_properties

    @property
    def global_properties(self):
        """Gets the global_properties of this BlockRemote.  # noqa: E501

        The extension's settings that apply all its widgets.  # noqa: E501

        :return: The global_properties of this BlockRemote.  # noqa: E501
        :rtype: object
        """
        return self._global_properties

    @global_properties.setter
    def global_properties(self, global_properties):
        """Sets the global_properties of this BlockRemote.

        The extension's settings that apply all its widgets.  # noqa: E501

        :param global_properties: The global_properties of this BlockRemote.  # noqa: E501
        :type: object
        """

        self._global_properties = global_properties

    @property
    def bundle_url(self):
        """Gets the bundle_url of this BlockRemote.  # noqa: E501

        The URL to download the extension's bundle.  # noqa: E501

        :return: The bundle_url of this BlockRemote.  # noqa: E501
        :rtype: str
        """
        return self._bundle_url

    @bundle_url.setter
    def bundle_url(self, bundle_url):
        """Sets the bundle_url of this BlockRemote.

        The URL to download the extension's bundle.  # noqa: E501

        :param bundle_url: The bundle_url of this BlockRemote.  # noqa: E501
        :type: str
        """

        self._bundle_url = bundle_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockRemote, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockRemote):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockUserProfilePreview(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "user_id": "str",
        "full_name": "str",
        "picture_url": "str",
        "fields": "list[UserProfileField]",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "user_id": "userId",
        "full_name": "fullName",
        "picture_url": "pictureUrl",
        "fields": "fields",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        user_id=None,
        full_name=None,
        picture_url=None,
        fields=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockUserProfilePreview - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._full_name = None
        self._picture_url = None
        self._fields = None
        self.discriminator = None
        self.user_id = user_id
        self.full_name = full_name
        self.picture_url = picture_url
        self.fields = fields
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def user_id(self):
        """Gets the user_id of this BlockUserProfilePreview.  # noqa: E501

        The user's id.  # noqa: E501

        :return: The user_id of this BlockUserProfilePreview.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BlockUserProfilePreview.

        The user's id.  # noqa: E501

        :param user_id: The user_id of this BlockUserProfilePreview.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError(
                "Invalid value for `user_id`, must not be `None`"
            )  # noqa: E501

        self._user_id = user_id

    @property
    def full_name(self):
        """Gets the full_name of this BlockUserProfilePreview.  # noqa: E501

        The user's full name.  # noqa: E501

        :return: The full_name of this BlockUserProfilePreview.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this BlockUserProfilePreview.

        The user's full name.  # noqa: E501

        :param full_name: The full_name of this BlockUserProfilePreview.  # noqa: E501
        :type: str
        """
        if full_name is None:
            raise ValueError(
                "Invalid value for `full_name`, must not be `None`"
            )  # noqa: E501

        self._full_name = full_name

    @property
    def picture_url(self):
        """Gets the picture_url of this BlockUserProfilePreview.  # noqa: E501

        The url to the user's profile picture.  # noqa: E501

        :return: The picture_url of this BlockUserProfilePreview.  # noqa: E501
        :rtype: str
        """
        return self._picture_url

    @picture_url.setter
    def picture_url(self, picture_url):
        """Sets the picture_url of this BlockUserProfilePreview.

        The url to the user's profile picture.  # noqa: E501

        :param picture_url: The picture_url of this BlockUserProfilePreview.  # noqa: E501
        :type: str
        """
        if picture_url is None:
            raise ValueError(
                "Invalid value for `picture_url`, must not be `None`"
            )  # noqa: E501

        self._picture_url = picture_url

    @property
    def fields(self):
        """Gets the fields of this BlockUserProfilePreview.  # noqa: E501

        a ordered field list from the user's profile  # noqa: E501

        :return: The fields of this BlockUserProfilePreview.  # noqa: E501
        :rtype: list[UserProfileField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this BlockUserProfilePreview.

        a ordered field list from the user's profile  # noqa: E501

        :param fields: The fields of this BlockUserProfilePreview.  # noqa: E501
        :type: list[UserProfileField]
        """
        if fields is None:
            raise ValueError(
                "Invalid value for `fields`, must not be `None`"
            )  # noqa: E501

        self._fields = fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockUserProfilePreview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockUserProfilePreview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class StructuredContent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "dita": "MultilangObject",
        "title": "I18nString",
        "intro": "I18nString",
        "featured_image": "MultilangDocument",
        "author_id": "str",
        "owner_users": "list[str]",
        "owner_groups": "list[str]",
        "updated_at": "datetime",
    }

    attribute_map = {
        "id": "id",
        "dita": "dita",
        "title": "title",
        "intro": "intro",
        "featured_image": "featuredImage",
        "author_id": "authorId",
        "owner_users": "ownerUsers",
        "owner_groups": "ownerGroups",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        id=None,
        dita=None,
        title=None,
        intro=None,
        featured_image=None,
        author_id=None,
        owner_users=None,
        owner_groups=None,
        updated_at=None,
    ):  # noqa: E501
        """StructuredContent - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._dita = None
        self._title = None
        self._intro = None
        self._featured_image = None
        self._author_id = None
        self._owner_users = None
        self._owner_groups = None
        self._updated_at = None
        self.discriminator = None
        self.id = id
        self.dita = dita
        self.title = title
        if intro is not None:
            self.intro = intro
        if featured_image is not None:
            self.featured_image = featured_image
        self.author_id = author_id
        self.owner_users = owner_users
        self.owner_groups = owner_groups
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this StructuredContent.  # noqa: E501

        The structured content id  # noqa: E501

        :return: The id of this StructuredContent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StructuredContent.

        The structured content id  # noqa: E501

        :param id: The id of this StructuredContent.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def dita(self):
        """Gets the dita of this StructuredContent.  # noqa: E501


        :return: The dita of this StructuredContent.  # noqa: E501
        :rtype: MultilangObject
        """
        return self._dita

    @dita.setter
    def dita(self, dita):
        """Sets the dita of this StructuredContent.


        :param dita: The dita of this StructuredContent.  # noqa: E501
        :type: MultilangObject
        """
        if dita is None:
            raise ValueError(
                "Invalid value for `dita`, must not be `None`"
            )  # noqa: E501

        self._dita = dita

    @property
    def title(self):
        """Gets the title of this StructuredContent.  # noqa: E501


        :return: The title of this StructuredContent.  # noqa: E501
        :rtype: I18nString
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this StructuredContent.


        :param title: The title of this StructuredContent.  # noqa: E501
        :type: I18nString
        """
        if title is None:
            raise ValueError(
                "Invalid value for `title`, must not be `None`"
            )  # noqa: E501

        self._title = title

    @property
    def intro(self):
        """Gets the intro of this StructuredContent.  # noqa: E501


        :return: The intro of this StructuredContent.  # noqa: E501
        :rtype: I18nString
        """
        return self._intro

    @intro.setter
    def intro(self, intro):
        """Sets the intro of this StructuredContent.


        :param intro: The intro of this StructuredContent.  # noqa: E501
        :type: I18nString
        """

        self._intro = intro

    @property
    def featured_image(self):
        """Gets the featured_image of this StructuredContent.  # noqa: E501


        :return: The featured_image of this StructuredContent.  # noqa: E501
        :rtype: MultilangDocument
        """
        return self._featured_image

    @featured_image.setter
    def featured_image(self, featured_image):
        """Sets the featured_image of this StructuredContent.


        :param featured_image: The featured_image of this StructuredContent.  # noqa: E501
        :type: MultilangDocument
        """

        self._featured_image = featured_image

    @property
    def author_id(self):
        """Gets the author_id of this StructuredContent.  # noqa: E501

        The author's user id  # noqa: E501

        :return: The author_id of this StructuredContent.  # noqa: E501
        :rtype: str
        """
        return self._author_id

    @author_id.setter
    def author_id(self, author_id):
        """Sets the author_id of this StructuredContent.

        The author's user id  # noqa: E501

        :param author_id: The author_id of this StructuredContent.  # noqa: E501
        :type: str
        """
        if author_id is None:
            raise ValueError(
                "Invalid value for `author_id`, must not be `None`"
            )  # noqa: E501

        self._author_id = author_id

    @property
    def owner_users(self):
        """Gets the owner_users of this StructuredContent.  # noqa: E501

        The owner user ids  # noqa: E501

        :return: The owner_users of this StructuredContent.  # noqa: E501
        :rtype: list[str]
        """
        return self._owner_users

    @owner_users.setter
    def owner_users(self, owner_users):
        """Sets the owner_users of this StructuredContent.

        The owner user ids  # noqa: E501

        :param owner_users: The owner_users of this StructuredContent.  # noqa: E501
        :type: list[str]
        """
        if owner_users is None:
            raise ValueError(
                "Invalid value for `owner_users`, must not be `None`"
            )  # noqa: E501

        self._owner_users = owner_users

    @property
    def owner_groups(self):
        """Gets the owner_groups of this StructuredContent.  # noqa: E501

        The owner group ids  # noqa: E501

        :return: The owner_groups of this StructuredContent.  # noqa: E501
        :rtype: list[str]
        """
        return self._owner_groups

    @owner_groups.setter
    def owner_groups(self, owner_groups):
        """Sets the owner_groups of this StructuredContent.

        The owner group ids  # noqa: E501

        :param owner_groups: The owner_groups of this StructuredContent.  # noqa: E501
        :type: list[str]
        """
        if owner_groups is None:
            raise ValueError(
                "Invalid value for `owner_groups`, must not be `None`"
            )  # noqa: E501

        self._owner_groups = owner_groups

    @property
    def updated_at(self):
        """Gets the updated_at of this StructuredContent.  # noqa: E501

        The date and time when the structured content was last updated  # noqa: E501

        :return: The updated_at of this StructuredContent.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this StructuredContent.

        The date and time when the structured content was last updated  # noqa: E501

        :param updated_at: The updated_at of this StructuredContent.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(StructuredContent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StructuredContent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from dataclasses import dataclass
from typing import Any, Callable

from oauthlib.oauth2 import BackendApplicationClient, OAuth2Error, TokenExpiredError
from requests_oauthlib import OAuth2Session

from .base import IClient, Request, Response
from .exceptions import InvalidLogin


@dataclass(frozen=True)
class Application:
    client_id: str
    client_secret: str


def retry_on_expired_token(func: Callable[..., Response]) -> Callable[..., Response]:
    def inner(client: "ApplicationClient", request: Request, **kwargs: Any) -> Response:
        try:
            return func(client, request, **kwargs)
        except TokenExpiredError:
            client.fetch_token()
            return func(client, request, **kwargs)

    return inner


class ApplicationClient(IClient):
    def __init__(
        self, base_url: str, organization_id: str, application: Application
    ) -> None:
        """
        Args:
            base_url: The API base url, i.e your Haussmann cell.
            e.g: https://XX-cell-YYY.api.lumapps.com
            organization_id: The ID of the given customer / organization.
            application: A LumApps application of the same customer.
        """
        self.base_url = base_url.rstrip("/")
        self.organization_id = organization_id
        self.application = application
        self.session = OAuth2Session(
            client=BackendApplicationClient(
                client_id=application.client_id,
                scope=None,
            )
        )
        self.organization_url = (
            f"{self.base_url}/v2/organizations/{self.organization_id}"
        )

    @retry_on_expired_token
    def request(self, request: Request, **_: Any) -> Response:
        if not self.session.token:
            # Ensure token in request
            self.fetch_token()
        response = self.session.request(
            request.method,
            f"{self.organization_url}/{request.url.lstrip('/')}",
            params=request.params,
            headers={
                **request.headers,
                "User-Agent": "lumapps-sdk",
                "x-lumapps-analytics": "off",
            },
            json=request.json,
        )
        return Response(
            status_code=response.status_code,
            headers=dict(response.headers),
            json=response.json() if response.text else None,
        )

    def fetch_token(self) -> None:
        try:
            self.session.fetch_token(
                f"{self.organization_url}/application-token",
                client_secret=self.application.client_secret,
            )
        except OAuth2Error as err:
            raise InvalidLogin("Could not fetch token from application") from err



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockCommunityPreview(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "community_id": "str",
        "site_id": "str",
        "slug": "str",
        "title": "str",
        "description": "str",
        "image": "BlockImage",
        "variant": "str",
        "are_social_buttons_visible": "bool",
        "is_followed": "bool",
        "are_notifications_enabled": "bool",
        "members": "list[BlockUser]",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "community_id": "communityId",
        "site_id": "siteId",
        "slug": "slug",
        "title": "title",
        "description": "description",
        "image": "image",
        "variant": "variant",
        "are_social_buttons_visible": "areSocialButtonsVisible",
        "is_followed": "isFollowed",
        "are_notifications_enabled": "areNotificationsEnabled",
        "members": "members",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        community_id=None,
        site_id=None,
        slug=None,
        title=None,
        description=None,
        image=None,
        variant=None,
        are_social_buttons_visible=None,
        is_followed=None,
        are_notifications_enabled=None,
        members=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockCommunityPreview - a model defined in Swagger"""  # noqa: E501
        self._community_id = None
        self._site_id = None
        self._slug = None
        self._title = None
        self._description = None
        self._image = None
        self._variant = None
        self._are_social_buttons_visible = None
        self._is_followed = None
        self._are_notifications_enabled = None
        self._members = None
        self.discriminator = None
        self.community_id = community_id
        self.site_id = site_id
        self.slug = slug
        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if image is not None:
            self.image = image
        self.variant = variant
        self.are_social_buttons_visible = are_social_buttons_visible
        if is_followed is not None:
            self.is_followed = is_followed
        if are_notifications_enabled is not None:
            self.are_notifications_enabled = are_notifications_enabled
        if members is not None:
            self.members = members
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def community_id(self):
        """Gets the community_id of this BlockCommunityPreview.  # noqa: E501

        The community's id.  # noqa: E501

        :return: The community_id of this BlockCommunityPreview.  # noqa: E501
        :rtype: str
        """
        return self._community_id

    @community_id.setter
    def community_id(self, community_id):
        """Sets the community_id of this BlockCommunityPreview.

        The community's id.  # noqa: E501

        :param community_id: The community_id of this BlockCommunityPreview.  # noqa: E501
        :type: str
        """
        if community_id is None:
            raise ValueError(
                "Invalid value for `community_id`, must not be `None`"
            )  # noqa: E501

        self._community_id = community_id

    @property
    def site_id(self):
        """Gets the site_id of this BlockCommunityPreview.  # noqa: E501

        The site's id.  # noqa: E501

        :return: The site_id of this BlockCommunityPreview.  # noqa: E501
        :rtype: str
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        """Sets the site_id of this BlockCommunityPreview.

        The site's id.  # noqa: E501

        :param site_id: The site_id of this BlockCommunityPreview.  # noqa: E501
        :type: str
        """
        if site_id is None:
            raise ValueError(
                "Invalid value for `site_id`, must not be `None`"
            )  # noqa: E501

        self._site_id = site_id

    @property
    def slug(self):
        """Gets the slug of this BlockCommunityPreview.  # noqa: E501

        The community's slug.  # noqa: E501

        :return: The slug of this BlockCommunityPreview.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this BlockCommunityPreview.

        The community's slug.  # noqa: E501

        :param slug: The slug of this BlockCommunityPreview.  # noqa: E501
        :type: str
        """
        if slug is None:
            raise ValueError(
                "Invalid value for `slug`, must not be `None`"
            )  # noqa: E501

        self._slug = slug

    @property
    def title(self):
        """Gets the title of this BlockCommunityPreview.  # noqa: E501

        The community's title.  # noqa: E501

        :return: The title of this BlockCommunityPreview.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BlockCommunityPreview.

        The community's title.  # noqa: E501

        :param title: The title of this BlockCommunityPreview.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this BlockCommunityPreview.  # noqa: E501

        The community's description.  # noqa: E501

        :return: The description of this BlockCommunityPreview.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BlockCommunityPreview.

        The community's description.  # noqa: E501

        :param description: The description of this BlockCommunityPreview.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def image(self):
        """Gets the image of this BlockCommunityPreview.  # noqa: E501


        :return: The image of this BlockCommunityPreview.  # noqa: E501
        :rtype: BlockImage
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this BlockCommunityPreview.


        :param image: The image of this BlockCommunityPreview.  # noqa: E501
        :type: BlockImage
        """

        self._image = image

    @property
    def variant(self):
        """Gets the variant of this BlockCommunityPreview.  # noqa: E501


        :return: The variant of this BlockCommunityPreview.  # noqa: E501
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this BlockCommunityPreview.


        :param variant: The variant of this BlockCommunityPreview.  # noqa: E501
        :type: str
        """
        if variant is None:
            raise ValueError(
                "Invalid value for `variant`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "VERTICAL",
            "VERTICAL_STRETCH",
            "HORIZONTAL",
            "HORIZONTAL_STRETCH",
        ]  # noqa: E501
        if variant not in allowed_values:
            raise ValueError(
                "Invalid value for `variant` ({0}), must be one of {1}".format(  # noqa: E501
                    variant, allowed_values
                )
            )

        self._variant = variant

    @property
    def are_social_buttons_visible(self):
        """Gets the are_social_buttons_visible of this BlockCommunityPreview.  # noqa: E501

        Whether the follow button and the notifications button must be displayed.  # noqa: E501

        :return: The are_social_buttons_visible of this BlockCommunityPreview.  # noqa: E501
        :rtype: bool
        """
        return self._are_social_buttons_visible

    @are_social_buttons_visible.setter
    def are_social_buttons_visible(self, are_social_buttons_visible):
        """Sets the are_social_buttons_visible of this BlockCommunityPreview.

        Whether the follow button and the notifications button must be displayed.  # noqa: E501

        :param are_social_buttons_visible: The are_social_buttons_visible of this BlockCommunityPreview.  # noqa: E501
        :type: bool
        """
        if are_social_buttons_visible is None:
            raise ValueError(
                "Invalid value for `are_social_buttons_visible`, must not be `None`"
            )  # noqa: E501

        self._are_social_buttons_visible = are_social_buttons_visible

    @property
    def is_followed(self):
        """Gets the is_followed of this BlockCommunityPreview.  # noqa: E501

        Whether the current user follows the community.  # noqa: E501

        :return: The is_followed of this BlockCommunityPreview.  # noqa: E501
        :rtype: bool
        """
        return self._is_followed

    @is_followed.setter
    def is_followed(self, is_followed):
        """Sets the is_followed of this BlockCommunityPreview.

        Whether the current user follows the community.  # noqa: E501

        :param is_followed: The is_followed of this BlockCommunityPreview.  # noqa: E501
        :type: bool
        """

        self._is_followed = is_followed

    @property
    def are_notifications_enabled(self):
        """Gets the are_notifications_enabled of this BlockCommunityPreview.  # noqa: E501

        Whether the current user has enabled notifications for the community.  # noqa: E501

        :return: The are_notifications_enabled of this BlockCommunityPreview.  # noqa: E501
        :rtype: bool
        """
        return self._are_notifications_enabled

    @are_notifications_enabled.setter
    def are_notifications_enabled(self, are_notifications_enabled):
        """Sets the are_notifications_enabled of this BlockCommunityPreview.

        Whether the current user has enabled notifications for the community.  # noqa: E501

        :param are_notifications_enabled: The are_notifications_enabled of this BlockCommunityPreview.  # noqa: E501
        :type: bool
        """

        self._are_notifications_enabled = are_notifications_enabled

    @property
    def members(self):
        """Gets the members of this BlockCommunityPreview.  # noqa: E501

        The first five members of the community, ordered by email ascending.  # noqa: E501

        :return: The members of this BlockCommunityPreview.  # noqa: E501
        :rtype: list[BlockUser]
        """
        return self._members

    @members.setter
    def members(self, members):
        """Sets the members of this BlockCommunityPreview.

        The first five members of the community, ordered by email ascending.  # noqa: E501

        :param members: The members of this BlockCommunityPreview.  # noqa: E501
        :type: list[BlockUser]
        """

        self._members = members

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockCommunityPreview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockCommunityPreview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Layout(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "is_v2_compatible": "bool",
        "revision_number": "int",
        "components": "list[object]",
        "widgets": "list[WidgetResponse]",
    }

    attribute_map = {
        "id": "id",
        "is_v2_compatible": "isV2Compatible",
        "revision_number": "revisionNumber",
        "components": "components",
        "widgets": "widgets",
    }

    def __init__(
        self,
        id=None,
        is_v2_compatible=None,
        revision_number=None,
        components=None,
        widgets=None,
    ):  # noqa: E501
        """Layout - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._is_v2_compatible = None
        self._revision_number = None
        self._components = None
        self._widgets = None
        self.discriminator = None
        self.id = id
        if is_v2_compatible is not None:
            self.is_v2_compatible = is_v2_compatible
        if revision_number is not None:
            self.revision_number = revision_number
        self.components = components
        if widgets is not None:
            self.widgets = widgets

    @property
    def id(self):
        """Gets the id of this Layout.  # noqa: E501


        :return: The id of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Layout.


        :param id: The id of this Layout.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_v2_compatible(self):
        """Gets the is_v2_compatible of this Layout.  # noqa: E501

        Whether all widgets presents in the layout are compatible with api v2  # noqa: E501

        :return: The is_v2_compatible of this Layout.  # noqa: E501
        :rtype: bool
        """
        return self._is_v2_compatible

    @is_v2_compatible.setter
    def is_v2_compatible(self, is_v2_compatible):
        """Sets the is_v2_compatible of this Layout.

        Whether all widgets presents in the layout are compatible with api v2  # noqa: E501

        :param is_v2_compatible: The is_v2_compatible of this Layout.  # noqa: E501
        :type: bool
        """

        self._is_v2_compatible = is_v2_compatible

    @property
    def revision_number(self):
        """Gets the revision_number of this Layout.  # noqa: E501


        :return: The revision_number of this Layout.  # noqa: E501
        :rtype: int
        """
        return self._revision_number

    @revision_number.setter
    def revision_number(self, revision_number):
        """Sets the revision_number of this Layout.


        :param revision_number: The revision_number of this Layout.  # noqa: E501
        :type: int
        """

        self._revision_number = revision_number

    @property
    def components(self):
        """Gets the components of this Layout.  # noqa: E501

        The layout components, which define the page structure.  # noqa: E501

        :return: The components of this Layout.  # noqa: E501
        :rtype: list[object]
        """
        return self._components

    @components.setter
    def components(self, components):
        """Sets the components of this Layout.

        The layout components, which define the page structure.  # noqa: E501

        :param components: The components of this Layout.  # noqa: E501
        :type: list[object]
        """
        if components is None:
            raise ValueError(
                "Invalid value for `components`, must not be `None`"
            )  # noqa: E501

        self._components = components

    @property
    def widgets(self):
        """Gets the widgets of this Layout.  # noqa: E501

        The pre-loaded display blocks for the widgets present in the layout.  # noqa: E501

        :return: The widgets of this Layout.  # noqa: E501
        :rtype: list[WidgetResponse]
        """
        return self._widgets

    @widgets.setter
    def widgets(self, widgets):
        """Sets the widgets of this Layout.

        The pre-loaded display blocks for the widgets present in the layout.  # noqa: E501

        :param widgets: The widgets of this Layout.  # noqa: E501
        :type: list[WidgetResponse]
        """

        self._widgets = widgets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Layout, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Layout):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Widget(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "widget_id": "str",
        "widget_type": "WidgetType",
        "header": "Header",
        "footer": "Footer",
        "body": "OneOfWidgetBody",
        "is_collapsed": "bool",
        "style": "ElementStyle",
        "css_class": "str",
        "html_id": "str",
    }

    attribute_map = {
        "widget_id": "widgetId",
        "widget_type": "widgetType",
        "header": "header",
        "footer": "footer",
        "body": "body",
        "is_collapsed": "isCollapsed",
        "style": "style",
        "css_class": "cssClass",
        "html_id": "htmlId",
    }

    def __init__(
        self,
        widget_id=None,
        widget_type=None,
        header=None,
        footer=None,
        body=None,
        is_collapsed=None,
        style=None,
        css_class=None,
        html_id=None,
    ):  # noqa: E501
        """Widget - a model defined in Swagger"""  # noqa: E501
        self._widget_id = None
        self._widget_type = None
        self._header = None
        self._footer = None
        self._body = None
        self._is_collapsed = None
        self._style = None
        self._css_class = None
        self._html_id = None
        self.discriminator = None
        self.widget_id = widget_id
        self.widget_type = widget_type
        if header is not None:
            self.header = header
        if footer is not None:
            self.footer = footer
        if body is not None:
            self.body = body
        self.is_collapsed = is_collapsed
        if style is not None:
            self.style = style
        if css_class is not None:
            self.css_class = css_class
        if html_id is not None:
            self.html_id = html_id

    @property
    def widget_id(self):
        """Gets the widget_id of this Widget.  # noqa: E501

        The widget's id.  # noqa: E501

        :return: The widget_id of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._widget_id

    @widget_id.setter
    def widget_id(self, widget_id):
        """Sets the widget_id of this Widget.

        The widget's id.  # noqa: E501

        :param widget_id: The widget_id of this Widget.  # noqa: E501
        :type: str
        """
        if widget_id is None:
            raise ValueError(
                "Invalid value for `widget_id`, must not be `None`"
            )  # noqa: E501

        self._widget_id = widget_id

    @property
    def widget_type(self):
        """Gets the widget_type of this Widget.  # noqa: E501


        :return: The widget_type of this Widget.  # noqa: E501
        :rtype: WidgetType
        """
        return self._widget_type

    @widget_type.setter
    def widget_type(self, widget_type):
        """Sets the widget_type of this Widget.


        :param widget_type: The widget_type of this Widget.  # noqa: E501
        :type: WidgetType
        """
        if widget_type is None:
            raise ValueError(
                "Invalid value for `widget_type`, must not be `None`"
            )  # noqa: E501

        self._widget_type = widget_type

    @property
    def header(self):
        """Gets the header of this Widget.  # noqa: E501


        :return: The header of this Widget.  # noqa: E501
        :rtype: Header
        """
        return self._header

    @header.setter
    def header(self, header):
        """Sets the header of this Widget.


        :param header: The header of this Widget.  # noqa: E501
        :type: Header
        """

        self._header = header

    @property
    def footer(self):
        """Gets the footer of this Widget.  # noqa: E501


        :return: The footer of this Widget.  # noqa: E501
        :rtype: Footer
        """
        return self._footer

    @footer.setter
    def footer(self, footer):
        """Sets the footer of this Widget.


        :param footer: The footer of this Widget.  # noqa: E501
        :type: Footer
        """

        self._footer = footer

    @property
    def body(self):
        """Gets the body of this Widget.  # noqa: E501


        :return: The body of this Widget.  # noqa: E501
        :rtype: OneOfWidgetBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this Widget.


        :param body: The body of this Widget.  # noqa: E501
        :type: OneOfWidgetBody
        """

        self._body = body

    @property
    def is_collapsed(self):
        """Gets the is_collapsed of this Widget.  # noqa: E501

        Whether the widget is collapsed upon load.  # noqa: E501

        :return: The is_collapsed of this Widget.  # noqa: E501
        :rtype: bool
        """
        return self._is_collapsed

    @is_collapsed.setter
    def is_collapsed(self, is_collapsed):
        """Sets the is_collapsed of this Widget.

        Whether the widget is collapsed upon load.  # noqa: E501

        :param is_collapsed: The is_collapsed of this Widget.  # noqa: E501
        :type: bool
        """
        if is_collapsed is None:
            raise ValueError(
                "Invalid value for `is_collapsed`, must not be `None`"
            )  # noqa: E501

        self._is_collapsed = is_collapsed

    @property
    def style(self):
        """Gets the style of this Widget.  # noqa: E501


        :return: The style of this Widget.  # noqa: E501
        :rtype: ElementStyle
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this Widget.


        :param style: The style of this Widget.  # noqa: E501
        :type: ElementStyle
        """

        self._style = style

    @property
    def css_class(self):
        """Gets the css_class of this Widget.  # noqa: E501

        The CSS class(es) used by this widget, if any.  # noqa: E501

        :return: The css_class of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._css_class

    @css_class.setter
    def css_class(self, css_class):
        """Sets the css_class of this Widget.

        The CSS class(es) used by this widget, if any.  # noqa: E501

        :param css_class: The css_class of this Widget.  # noqa: E501
        :type: str
        """

        self._css_class = css_class

    @property
    def html_id(self):
        """Gets the html_id of this Widget.  # noqa: E501

        The HTML id used by this widget, if any.  # noqa: E501

        :return: The html_id of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._html_id

    @html_id.setter
    def html_id(self, html_id):
        """Sets the html_id of this Widget.

        The HTML id used by this widget, if any.  # noqa: E501

        :param html_id: The html_id of this Widget.  # noqa: E501
        :type: str
        """

        self._html_id = html_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Widget, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Widget):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockVotes(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "resource_type": "str",
        "resource_id": "str",
        "up_votes": "int",
        "down_votes": "int",
        "user_vote": "str",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "resource_type": "resourceType",
        "resource_id": "resourceId",
        "up_votes": "upVotes",
        "down_votes": "downVotes",
        "user_vote": "userVote",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        resource_type=None,
        resource_id=None,
        up_votes=None,
        down_votes=None,
        user_vote=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockVotes - a model defined in Swagger"""  # noqa: E501
        self._resource_type = None
        self._resource_id = None
        self._up_votes = None
        self._down_votes = None
        self._user_vote = None
        self.discriminator = None
        self.resource_type = resource_type
        self.resource_id = resource_id
        self.up_votes = up_votes
        self.down_votes = down_votes
        self.user_vote = user_vote
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def resource_type(self):
        """Gets the resource_type of this BlockVotes.  # noqa: E501

        The type of the associated resource.  # noqa: E501

        :return: The resource_type of this BlockVotes.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this BlockVotes.

        The type of the associated resource.  # noqa: E501

        :param resource_type: The resource_type of this BlockVotes.  # noqa: E501
        :type: str
        """
        if resource_type is None:
            raise ValueError(
                "Invalid value for `resource_type`, must not be `None`"
            )  # noqa: E501

        self._resource_type = resource_type

    @property
    def resource_id(self):
        """Gets the resource_id of this BlockVotes.  # noqa: E501

        The id of the associated resource.  # noqa: E501

        :return: The resource_id of this BlockVotes.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this BlockVotes.

        The id of the associated resource.  # noqa: E501

        :param resource_id: The resource_id of this BlockVotes.  # noqa: E501
        :type: str
        """
        if resource_id is None:
            raise ValueError(
                "Invalid value for `resource_id`, must not be `None`"
            )  # noqa: E501

        self._resource_id = resource_id

    @property
    def up_votes(self):
        """Gets the up_votes of this BlockVotes.  # noqa: E501

        The number of upvotes for the associated resource.  # noqa: E501

        :return: The up_votes of this BlockVotes.  # noqa: E501
        :rtype: int
        """
        return self._up_votes

    @up_votes.setter
    def up_votes(self, up_votes):
        """Sets the up_votes of this BlockVotes.

        The number of upvotes for the associated resource.  # noqa: E501

        :param up_votes: The up_votes of this BlockVotes.  # noqa: E501
        :type: int
        """
        if up_votes is None:
            raise ValueError(
                "Invalid value for `up_votes`, must not be `None`"
            )  # noqa: E501

        self._up_votes = up_votes

    @property
    def down_votes(self):
        """Gets the down_votes of this BlockVotes.  # noqa: E501

        The number of downvotes for the associated resource.  # noqa: E501

        :return: The down_votes of this BlockVotes.  # noqa: E501
        :rtype: int
        """
        return self._down_votes

    @down_votes.setter
    def down_votes(self, down_votes):
        """Sets the down_votes of this BlockVotes.

        The number of downvotes for the associated resource.  # noqa: E501

        :param down_votes: The down_votes of this BlockVotes.  # noqa: E501
        :type: int
        """
        if down_votes is None:
            raise ValueError(
                "Invalid value for `down_votes`, must not be `None`"
            )  # noqa: E501

        self._down_votes = down_votes

    @property
    def user_vote(self):
        """Gets the user_vote of this BlockVotes.  # noqa: E501

        The user vote for the associated resource.  # noqa: E501

        :return: The user_vote of this BlockVotes.  # noqa: E501
        :rtype: str
        """
        return self._user_vote

    @user_vote.setter
    def user_vote(self, user_vote):
        """Sets the user_vote of this BlockVotes.

        The user vote for the associated resource.  # noqa: E501

        :param user_vote: The user_vote of this BlockVotes.  # noqa: E501
        :type: str
        """
        if user_vote is None:
            raise ValueError(
                "Invalid value for `user_vote`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["NONE", "UP", "DOWN"]  # noqa: E501
        if user_vote not in allowed_values:
            raise ValueError(
                "Invalid value for `user_vote` ({0}), must be one of {1}".format(  # noqa: E501
                    user_vote, allowed_values
                )
            )

        self._user_vote = user_vote

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockVotes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockVotes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockClientComputed(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "legacy_widget_type": "str",
        "widget_type": "str",
        "properties": "object",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "legacy_widget_type": "legacyWidgetType",
        "widget_type": "widgetType",
        "properties": "properties",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        legacy_widget_type=None,
        widget_type=None,
        properties=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockClientComputed - a model defined in Swagger"""  # noqa: E501
        self._legacy_widget_type = None
        self._widget_type = None
        self._properties = None
        self.discriminator = None
        if legacy_widget_type is not None:
            self.legacy_widget_type = legacy_widget_type
        if widget_type is not None:
            self.widget_type = widget_type
        if properties is not None:
            self.properties = properties
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def legacy_widget_type(self):
        """Gets the legacy_widget_type of this BlockClientComputed.  # noqa: E501

        DEPRECATED use widgetType instead.  # noqa: E501

        :return: The legacy_widget_type of this BlockClientComputed.  # noqa: E501
        :rtype: str
        """
        return self._legacy_widget_type

    @legacy_widget_type.setter
    def legacy_widget_type(self, legacy_widget_type):
        """Sets the legacy_widget_type of this BlockClientComputed.

        DEPRECATED use widgetType instead.  # noqa: E501

        :param legacy_widget_type: The legacy_widget_type of this BlockClientComputed.  # noqa: E501
        :type: str
        """

        self._legacy_widget_type = legacy_widget_type

    @property
    def widget_type(self):
        """Gets the widget_type of this BlockClientComputed.  # noqa: E501

        Used to identify the kind of widget that this block represents.  # noqa: E501

        :return: The widget_type of this BlockClientComputed.  # noqa: E501
        :rtype: str
        """
        return self._widget_type

    @widget_type.setter
    def widget_type(self, widget_type):
        """Sets the widget_type of this BlockClientComputed.

        Used to identify the kind of widget that this block represents.  # noqa: E501

        :param widget_type: The widget_type of this BlockClientComputed.  # noqa: E501
        :type: str
        """

        self._widget_type = widget_type

    @property
    def properties(self):
        """Gets the properties of this BlockClientComputed.  # noqa: E501

        The additional properties used by the client to render this block.  # noqa: E501

        :return: The properties of this BlockClientComputed.  # noqa: E501
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BlockClientComputed.

        The additional properties used by the client to render this block.  # noqa: E501

        :param properties: The properties of this BlockClientComputed.  # noqa: E501
        :type: object
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockClientComputed, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockClientComputed):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockPost(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "post_id": "str",
        "post_type": "str",
        "community": "CommunityInfo",
        "site": "SiteReference",
        "author": "UserReference",
        "reports": "BlockInappropriate",
        "shares": "list[PostShare]",
        "share_count": "int",
        "event_starts_at": "datetime",
        "event_ends_at": "datetime",
        "is_answered": "bool",
        "title": "str",
        "content": "str",
        "visible_lines": "int",
        "can_share": "bool",
        "can_edit": "bool",
        "can_move": "bool",
        "can_delete": "bool",
        "user_mentions": "list[UserReference]",
        "links": "list[AttachedLink]",
        "tags": "BlockTagReferenceList",
        "files": "list[MediaPreview]",
        "images": "list[MediaPreview]",
        "reactions": "BlockReactions",
        "votes": "BlockVotes",
        "idea_status": "IdeaStatus",
        "article_preview": "ArticlePreview",
        "play_video_preview": "PlayVideoPreview",
        "order": "list[str]",
        "version": "int",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "post_id": "postId",
        "post_type": "postType",
        "community": "community",
        "site": "site",
        "author": "author",
        "reports": "reports",
        "shares": "shares",
        "share_count": "shareCount",
        "event_starts_at": "eventStartsAt",
        "event_ends_at": "eventEndsAt",
        "is_answered": "isAnswered",
        "title": "title",
        "content": "content",
        "visible_lines": "visibleLines",
        "can_share": "canShare",
        "can_edit": "canEdit",
        "can_move": "canMove",
        "can_delete": "canDelete",
        "user_mentions": "userMentions",
        "links": "links",
        "tags": "tags",
        "files": "files",
        "images": "images",
        "reactions": "reactions",
        "votes": "votes",
        "idea_status": "ideaStatus",
        "article_preview": "articlePreview",
        "play_video_preview": "playVideoPreview",
        "order": "order",
        "version": "version",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        post_id=None,
        post_type=None,
        community=None,
        site=None,
        author=None,
        reports=None,
        shares=None,
        share_count=None,
        event_starts_at=None,
        event_ends_at=None,
        is_answered=None,
        title=None,
        content=None,
        visible_lines=10,
        can_share=None,
        can_edit=None,
        can_move=None,
        can_delete=None,
        user_mentions=None,
        links=None,
        tags=None,
        files=None,
        images=None,
        reactions=None,
        votes=None,
        idea_status=None,
        article_preview=None,
        play_video_preview=None,
        order=None,
        version=0,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockPost - a model defined in Swagger"""  # noqa: E501
        self._post_id = None
        self._post_type = None
        self._community = None
        self._site = None
        self._author = None
        self._reports = None
        self._shares = None
        self._share_count = None
        self._event_starts_at = None
        self._event_ends_at = None
        self._is_answered = None
        self._title = None
        self._content = None
        self._visible_lines = None
        self._can_share = None
        self._can_edit = None
        self._can_move = None
        self._can_delete = None
        self._user_mentions = None
        self._links = None
        self._tags = None
        self._files = None
        self._images = None
        self._reactions = None
        self._votes = None
        self._idea_status = None
        self._article_preview = None
        self._play_video_preview = None
        self._order = None
        self._version = None
        self.discriminator = None
        self.post_id = post_id
        self.post_type = post_type
        self.community = community
        self.site = site
        self.author = author
        if reports is not None:
            self.reports = reports
        self.shares = shares
        self.share_count = share_count
        if event_starts_at is not None:
            self.event_starts_at = event_starts_at
        if event_ends_at is not None:
            self.event_ends_at = event_ends_at
        if is_answered is not None:
            self.is_answered = is_answered
        if title is not None:
            self.title = title
        if content is not None:
            self.content = content
        self.visible_lines = visible_lines
        self.can_share = can_share
        self.can_edit = can_edit
        self.can_move = can_move
        self.can_delete = can_delete
        if user_mentions is not None:
            self.user_mentions = user_mentions
        if links is not None:
            self.links = links
        if tags is not None:
            self.tags = tags
        if files is not None:
            self.files = files
        if images is not None:
            self.images = images
        if reactions is not None:
            self.reactions = reactions
        if votes is not None:
            self.votes = votes
        if idea_status is not None:
            self.idea_status = idea_status
        if article_preview is not None:
            self.article_preview = article_preview
        if play_video_preview is not None:
            self.play_video_preview = play_video_preview
        if order is not None:
            self.order = order
        self.version = version
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def post_id(self):
        """Gets the post_id of this BlockPost.  # noqa: E501

        The post's id.  # noqa: E501

        :return: The post_id of this BlockPost.  # noqa: E501
        :rtype: str
        """
        return self._post_id

    @post_id.setter
    def post_id(self, post_id):
        """Sets the post_id of this BlockPost.

        The post's id.  # noqa: E501

        :param post_id: The post_id of this BlockPost.  # noqa: E501
        :type: str
        """
        if post_id is None:
            raise ValueError(
                "Invalid value for `post_id`, must not be `None`"
            )  # noqa: E501

        self._post_id = post_id

    @property
    def post_type(self):
        """Gets the post_type of this BlockPost.  # noqa: E501

        The post's type.  # noqa: E501

        :return: The post_type of this BlockPost.  # noqa: E501
        :rtype: str
        """
        return self._post_type

    @post_type.setter
    def post_type(self, post_type):
        """Sets the post_type of this BlockPost.

        The post's type.  # noqa: E501

        :param post_type: The post_type of this BlockPost.  # noqa: E501
        :type: str
        """
        if post_type is None:
            raise ValueError(
                "Invalid value for `post_type`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["DEFAULT", "EVENT", "IDEA", "QUESTION"]  # noqa: E501
        if post_type not in allowed_values:
            raise ValueError(
                "Invalid value for `post_type` ({0}), must be one of {1}".format(  # noqa: E501
                    post_type, allowed_values
                )
            )

        self._post_type = post_type

    @property
    def community(self):
        """Gets the community of this BlockPost.  # noqa: E501


        :return: The community of this BlockPost.  # noqa: E501
        :rtype: CommunityInfo
        """
        return self._community

    @community.setter
    def community(self, community):
        """Sets the community of this BlockPost.


        :param community: The community of this BlockPost.  # noqa: E501
        :type: CommunityInfo
        """
        if community is None:
            raise ValueError(
                "Invalid value for `community`, must not be `None`"
            )  # noqa: E501

        self._community = community

    @property
    def site(self):
        """Gets the site of this BlockPost.  # noqa: E501


        :return: The site of this BlockPost.  # noqa: E501
        :rtype: SiteReference
        """
        return self._site

    @site.setter
    def site(self, site):
        """Sets the site of this BlockPost.


        :param site: The site of this BlockPost.  # noqa: E501
        :type: SiteReference
        """
        if site is None:
            raise ValueError(
                "Invalid value for `site`, must not be `None`"
            )  # noqa: E501

        self._site = site

    @property
    def author(self):
        """Gets the author of this BlockPost.  # noqa: E501


        :return: The author of this BlockPost.  # noqa: E501
        :rtype: UserReference
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this BlockPost.


        :param author: The author of this BlockPost.  # noqa: E501
        :type: UserReference
        """
        if author is None:
            raise ValueError(
                "Invalid value for `author`, must not be `None`"
            )  # noqa: E501

        self._author = author

    @property
    def reports(self):
        """Gets the reports of this BlockPost.  # noqa: E501


        :return: The reports of this BlockPost.  # noqa: E501
        :rtype: BlockInappropriate
        """
        return self._reports

    @reports.setter
    def reports(self, reports):
        """Sets the reports of this BlockPost.


        :param reports: The reports of this BlockPost.  # noqa: E501
        :type: BlockInappropriate
        """

        self._reports = reports

    @property
    def shares(self):
        """Gets the shares of this BlockPost.  # noqa: E501


        :return: The shares of this BlockPost.  # noqa: E501
        :rtype: list[PostShare]
        """
        return self._shares

    @shares.setter
    def shares(self, shares):
        """Sets the shares of this BlockPost.


        :param shares: The shares of this BlockPost.  # noqa: E501
        :type: list[PostShare]
        """
        if shares is None:
            raise ValueError(
                "Invalid value for `shares`, must not be `None`"
            )  # noqa: E501

        self._shares = shares

    @property
    def share_count(self):
        """Gets the share_count of this BlockPost.  # noqa: E501

        The number of communities where the post is shared, regardless of user permissions.  # noqa: E501

        :return: The share_count of this BlockPost.  # noqa: E501
        :rtype: int
        """
        return self._share_count

    @share_count.setter
    def share_count(self, share_count):
        """Sets the share_count of this BlockPost.

        The number of communities where the post is shared, regardless of user permissions.  # noqa: E501

        :param share_count: The share_count of this BlockPost.  # noqa: E501
        :type: int
        """
        if share_count is None:
            raise ValueError(
                "Invalid value for `share_count`, must not be `None`"
            )  # noqa: E501

        self._share_count = share_count

    @property
    def event_starts_at(self):
        """Gets the event_starts_at of this BlockPost.  # noqa: E501

        The event start date and time.  # noqa: E501

        :return: The event_starts_at of this BlockPost.  # noqa: E501
        :rtype: datetime
        """
        return self._event_starts_at

    @event_starts_at.setter
    def event_starts_at(self, event_starts_at):
        """Sets the event_starts_at of this BlockPost.

        The event start date and time.  # noqa: E501

        :param event_starts_at: The event_starts_at of this BlockPost.  # noqa: E501
        :type: datetime
        """

        self._event_starts_at = event_starts_at

    @property
    def event_ends_at(self):
        """Gets the event_ends_at of this BlockPost.  # noqa: E501

        The event end date and time.  # noqa: E501

        :return: The event_ends_at of this BlockPost.  # noqa: E501
        :rtype: datetime
        """
        return self._event_ends_at

    @event_ends_at.setter
    def event_ends_at(self, event_ends_at):
        """Sets the event_ends_at of this BlockPost.

        The event end date and time.  # noqa: E501

        :param event_ends_at: The event_ends_at of this BlockPost.  # noqa: E501
        :type: datetime
        """

        self._event_ends_at = event_ends_at

    @property
    def is_answered(self):
        """Gets the is_answered of this BlockPost.  # noqa: E501

        Whether the question asked in the post is answered.  # noqa: E501

        :return: The is_answered of this BlockPost.  # noqa: E501
        :rtype: bool
        """
        return self._is_answered

    @is_answered.setter
    def is_answered(self, is_answered):
        """Sets the is_answered of this BlockPost.

        Whether the question asked in the post is answered.  # noqa: E501

        :param is_answered: The is_answered of this BlockPost.  # noqa: E501
        :type: bool
        """

        self._is_answered = is_answered

    @property
    def title(self):
        """Gets the title of this BlockPost.  # noqa: E501

        The post's title.  # noqa: E501

        :return: The title of this BlockPost.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BlockPost.

        The post's title.  # noqa: E501

        :param title: The title of this BlockPost.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def content(self):
        """Gets the content of this BlockPost.  # noqa: E501

        The post's content, in markdown or DITA format.  # noqa: E501

        :return: The content of this BlockPost.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this BlockPost.

        The post's content, in markdown or DITA format.  # noqa: E501

        :param content: The content of this BlockPost.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def visible_lines(self):
        """Gets the visible_lines of this BlockPost.  # noqa: E501

        The number of lines of the post's content that are visible  # noqa: E501

        :return: The visible_lines of this BlockPost.  # noqa: E501
        :rtype: int
        """
        return self._visible_lines

    @visible_lines.setter
    def visible_lines(self, visible_lines):
        """Sets the visible_lines of this BlockPost.

        The number of lines of the post's content that are visible  # noqa: E501

        :param visible_lines: The visible_lines of this BlockPost.  # noqa: E501
        :type: int
        """
        if visible_lines is None:
            raise ValueError(
                "Invalid value for `visible_lines`, must not be `None`"
            )  # noqa: E501

        self._visible_lines = visible_lines

    @property
    def can_share(self):
        """Gets the can_share of this BlockPost.  # noqa: E501

        Whether the user is allowed to share the post to other communities.  # noqa: E501

        :return: The can_share of this BlockPost.  # noqa: E501
        :rtype: bool
        """
        return self._can_share

    @can_share.setter
    def can_share(self, can_share):
        """Sets the can_share of this BlockPost.

        Whether the user is allowed to share the post to other communities.  # noqa: E501

        :param can_share: The can_share of this BlockPost.  # noqa: E501
        :type: bool
        """
        if can_share is None:
            raise ValueError(
                "Invalid value for `can_share`, must not be `None`"
            )  # noqa: E501

        self._can_share = can_share

    @property
    def can_edit(self):
        """Gets the can_edit of this BlockPost.  # noqa: E501

        Whether the user is allowed to edit the post.  # noqa: E501

        :return: The can_edit of this BlockPost.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit

    @can_edit.setter
    def can_edit(self, can_edit):
        """Sets the can_edit of this BlockPost.

        Whether the user is allowed to edit the post.  # noqa: E501

        :param can_edit: The can_edit of this BlockPost.  # noqa: E501
        :type: bool
        """
        if can_edit is None:
            raise ValueError(
                "Invalid value for `can_edit`, must not be `None`"
            )  # noqa: E501

        self._can_edit = can_edit

    @property
    def can_move(self):
        """Gets the can_move of this BlockPost.  # noqa: E501

        Whether the user is allowed to move the post to a different community.  # noqa: E501

        :return: The can_move of this BlockPost.  # noqa: E501
        :rtype: bool
        """
        return self._can_move

    @can_move.setter
    def can_move(self, can_move):
        """Sets the can_move of this BlockPost.

        Whether the user is allowed to move the post to a different community.  # noqa: E501

        :param can_move: The can_move of this BlockPost.  # noqa: E501
        :type: bool
        """
        if can_move is None:
            raise ValueError(
                "Invalid value for `can_move`, must not be `None`"
            )  # noqa: E501

        self._can_move = can_move

    @property
    def can_delete(self):
        """Gets the can_delete of this BlockPost.  # noqa: E501

        Whether the user is allowed to delete the post.  # noqa: E501

        :return: The can_delete of this BlockPost.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete

    @can_delete.setter
    def can_delete(self, can_delete):
        """Sets the can_delete of this BlockPost.

        Whether the user is allowed to delete the post.  # noqa: E501

        :param can_delete: The can_delete of this BlockPost.  # noqa: E501
        :type: bool
        """
        if can_delete is None:
            raise ValueError(
                "Invalid value for `can_delete`, must not be `None`"
            )  # noqa: E501

        self._can_delete = can_delete

    @property
    def user_mentions(self):
        """Gets the user_mentions of this BlockPost.  # noqa: E501

        The users mentioned in the post.  # noqa: E501

        :return: The user_mentions of this BlockPost.  # noqa: E501
        :rtype: list[UserReference]
        """
        return self._user_mentions

    @user_mentions.setter
    def user_mentions(self, user_mentions):
        """Sets the user_mentions of this BlockPost.

        The users mentioned in the post.  # noqa: E501

        :param user_mentions: The user_mentions of this BlockPost.  # noqa: E501
        :type: list[UserReference]
        """

        self._user_mentions = user_mentions

    @property
    def links(self):
        """Gets the links of this BlockPost.  # noqa: E501

        The links attached to the post.  # noqa: E501

        :return: The links of this BlockPost.  # noqa: E501
        :rtype: list[AttachedLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this BlockPost.

        The links attached to the post.  # noqa: E501

        :param links: The links of this BlockPost.  # noqa: E501
        :type: list[AttachedLink]
        """

        self._links = links

    @property
    def tags(self):
        """Gets the tags of this BlockPost.  # noqa: E501


        :return: The tags of this BlockPost.  # noqa: E501
        :rtype: BlockTagReferenceList
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this BlockPost.


        :param tags: The tags of this BlockPost.  # noqa: E501
        :type: BlockTagReferenceList
        """

        self._tags = tags

    @property
    def files(self):
        """Gets the files of this BlockPost.  # noqa: E501

        The files attached to the post.  # noqa: E501

        :return: The files of this BlockPost.  # noqa: E501
        :rtype: list[MediaPreview]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this BlockPost.

        The files attached to the post.  # noqa: E501

        :param files: The files of this BlockPost.  # noqa: E501
        :type: list[MediaPreview]
        """

        self._files = files

    @property
    def images(self):
        """Gets the images of this BlockPost.  # noqa: E501

        The images attached to the post.  # noqa: E501

        :return: The images of this BlockPost.  # noqa: E501
        :rtype: list[MediaPreview]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this BlockPost.

        The images attached to the post.  # noqa: E501

        :param images: The images of this BlockPost.  # noqa: E501
        :type: list[MediaPreview]
        """

        self._images = images

    @property
    def reactions(self):
        """Gets the reactions of this BlockPost.  # noqa: E501


        :return: The reactions of this BlockPost.  # noqa: E501
        :rtype: BlockReactions
        """
        return self._reactions

    @reactions.setter
    def reactions(self, reactions):
        """Sets the reactions of this BlockPost.


        :param reactions: The reactions of this BlockPost.  # noqa: E501
        :type: BlockReactions
        """

        self._reactions = reactions

    @property
    def votes(self):
        """Gets the votes of this BlockPost.  # noqa: E501


        :return: The votes of this BlockPost.  # noqa: E501
        :rtype: BlockVotes
        """
        return self._votes

    @votes.setter
    def votes(self, votes):
        """Sets the votes of this BlockPost.


        :param votes: The votes of this BlockPost.  # noqa: E501
        :type: BlockVotes
        """

        self._votes = votes

    @property
    def idea_status(self):
        """Gets the idea_status of this BlockPost.  # noqa: E501


        :return: The idea_status of this BlockPost.  # noqa: E501
        :rtype: IdeaStatus
        """
        return self._idea_status

    @idea_status.setter
    def idea_status(self, idea_status):
        """Sets the idea_status of this BlockPost.


        :param idea_status: The idea_status of this BlockPost.  # noqa: E501
        :type: IdeaStatus
        """

        self._idea_status = idea_status

    @property
    def article_preview(self):
        """Gets the article_preview of this BlockPost.  # noqa: E501


        :return: The article_preview of this BlockPost.  # noqa: E501
        :rtype: ArticlePreview
        """
        return self._article_preview

    @article_preview.setter
    def article_preview(self, article_preview):
        """Sets the article_preview of this BlockPost.


        :param article_preview: The article_preview of this BlockPost.  # noqa: E501
        :type: ArticlePreview
        """

        self._article_preview = article_preview

    @property
    def play_video_preview(self):
        """Gets the play_video_preview of this BlockPost.  # noqa: E501


        :return: The play_video_preview of this BlockPost.  # noqa: E501
        :rtype: PlayVideoPreview
        """
        return self._play_video_preview

    @play_video_preview.setter
    def play_video_preview(self, play_video_preview):
        """Sets the play_video_preview of this BlockPost.


        :param play_video_preview: The play_video_preview of this BlockPost.  # noqa: E501
        :type: PlayVideoPreview
        """

        self._play_video_preview = play_video_preview

    @property
    def order(self):
        """Gets the order of this BlockPost.  # noqa: E501

        The display order of the properties.  # noqa: E501

        :return: The order of this BlockPost.  # noqa: E501
        :rtype: list[str]
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this BlockPost.

        The display order of the properties.  # noqa: E501

        :param order: The order of this BlockPost.  # noqa: E501
        :type: list[str]
        """

        self._order = order

    @property
    def version(self):
        """Gets the version of this BlockPost.  # noqa: E501

        The post version, incremented after each edition.  # noqa: E501

        :return: The version of this BlockPost.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BlockPost.

        The post version, incremented after each edition.  # noqa: E501

        :param version: The version of this BlockPost.  # noqa: E501
        :type: int
        """
        if version is None:
            raise ValueError(
                "Invalid value for `version`, must not be `None`"
            )  # noqa: E501

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockPost, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockPost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import datetime
import mimetypes
import os
import re
import tempfile

from lumapps.latest.api.exceptions import ApiException


class SerializationError(ApiException):
    pass


class Serialization(object):

    PRIMITIVE_TYPES = (float, bool, bytes, str, int)
    NATIVE_TYPES_MAPPING = {
        "int": int,
        "long": int,
        "float": float,
        "str": str,
        "bool": bool,
        "date": datetime.date,
        "datetime": datetime.datetime,
        "object": object,
    }

    def __init__(self, models) -> None:
        self.models = models

    def sanitize_for_serialization(self, obj):
        """Builds a JSON POST object.

        If obj is None, return None.
        If obj is str, int, long, float, bool, return directly.
        If obj is datetime.datetime, datetime.date
            convert to string in iso8601 format.
        If obj is list, sanitize each element in the list.
        If obj is dict, return the dict.
        If obj is swagger model, return the properties dict.

        :param obj: The data to serialize.
        :return: The serialized form of data.
        """
        if obj is None:
            return None
        elif isinstance(obj, self.PRIMITIVE_TYPES):
            return obj
        elif isinstance(obj, list):
            return [self.sanitize_for_serialization(sub_obj) for sub_obj in obj]
        elif isinstance(obj, tuple):
            return tuple(self.sanitize_for_serialization(sub_obj) for sub_obj in obj)
        elif isinstance(obj, (datetime.datetime, datetime.date)):
            return obj.isoformat()

        if isinstance(obj, dict):
            obj_dict = obj
        else:
            # Convert model obj to dict except
            # attributes `swagger_types`, `attribute_map`
            # and attributes which value is not None.
            # Convert attribute name to json key in
            # model definition for request.
            obj_dict = {
                obj.attribute_map[attr]: getattr(obj, attr)
                for attr, _ in obj.swagger_types.items()
                if getattr(obj, attr) is not None
            }

        return {
            key: self.sanitize_for_serialization(val) for key, val in obj_dict.items()
        }

    def deserialize(self, data: dict, klass):
        """Deserializes dict, list, str into an object.

        :param data: dict, list or str.
        :param klass: class literal, or string of class name.

        :return: object.
        """
        if data is None:
            return None

        if type(klass) == str:
            if klass.startswith("list["):
                sub_kls = re.match(r"list\[(.*)\]", klass).group(1)
                return [self.deserialize(sub_data, sub_kls) for sub_data in data]

            if klass.startswith("dict("):
                sub_kls = re.match(r"dict\(([^,]*), (.*)\)", klass).group(2)
                return {k: self.deserialize(v, sub_kls) for k, v in data.items()}

            # convert str to class
            if klass in self.NATIVE_TYPES_MAPPING:
                klass = self.NATIVE_TYPES_MAPPING[klass]
            else:
                klass = getattr(self.models, klass)

        if klass in self.PRIMITIVE_TYPES:
            return self.__deserialize_primitive(data, klass)
        elif klass == object:
            return self.__deserialize_object(data)
        elif klass == datetime.date:
            return self.__deserialize_date(data)
        elif klass == datetime.datetime:
            return self.__deserialize_datatime(data)
        else:
            return self.__deserialize_model(data, klass)

    def parameters_to_tuples(self, params, collection_formats):
        """Get parameters as list of tuples, formatting collections.

        :param params: Parameters as dict or list of two-tuples
        :param dict collection_formats: Parameter collection formats
        :return: Parameters as list of tuples, collections formatted
        """
        new_params = []
        if collection_formats is None:
            collection_formats = {}
        for k, v in (
            params.items() if isinstance(params, dict) else params
        ):  # noqa: E501
            if k in collection_formats:
                collection_format = collection_formats[k]
                if collection_format == "multi":
                    new_params.extend((k, value) for value in v)
                else:
                    if collection_format == "ssv":
                        delimiter = " "
                    elif collection_format == "tsv":
                        delimiter = "\t"
                    elif collection_format == "pipes":
                        delimiter = "|"
                    else:  # csv is the default
                        delimiter = ","
                    new_params.append((k, delimiter.join(str(value) for value in v)))
            else:
                new_params.append((k, v))
        return new_params

    def prepare_post_parameters(self, post_params=None, files=None):
        """Builds form parameters.

        :param post_params: Normal form parameters.
        :param files: File parameters.
        :return: Form parameters with files.
        """
        params = []

        if post_params:
            params = post_params

        if files:
            for k, v in files.items():
                if not v:
                    continue
                file_names = v if type(v) is list else [v]
                for n in file_names:
                    with open(n, "rb") as f:
                        filename = os.path.basename(f.name)
                        filedata = f.read()
                        mimetype = (
                            mimetypes.guess_type(filename)[0]
                            or "application/octet-stream"
                        )
                        params.append(tuple([k, tuple([filename, filedata, mimetype])]))

        return params

    def select_header_accept(self, accepts):
        """Returns `Accept` based on an array of accepts provided.

        :param accepts: List of headers.
        :return: Accept (e.g. application/json).
        """
        if not accepts:
            return

        accepts = [x.lower() for x in accepts]

        if "application/json" in accepts:
            return "application/json"
        else:
            return ", ".join(accepts)

    def select_header_content_type(self, content_types):
        """Returns `Content-Type` based on an array of content_types provided.

        :param content_types: List of content-types.
        :return: Content-Type (e.g. application/json).
        """
        if not content_types:
            return "application/json"

        content_types = [x.lower() for x in content_types]

        if "application/json" in content_types or "*/*" in content_types:
            return "application/json"
        else:
            return content_types[0]

    def update_params_for_auth(self, headers, querys, auth_settings):
        """Updates header and query params based on authentication setting.

        :param headers: Header parameters dict to be updated.
        :param querys: Query parameters tuple list to be updated.
        :param auth_settings: Authentication setting identifiers list.
        """
        if not auth_settings:
            return

        for auth in auth_settings:
            auth_setting = self.configuration.auth_settings().get(auth)
            if auth_setting:
                if not auth_setting["value"]:
                    continue
                elif auth_setting["in"] == "header":
                    headers[auth_setting["key"]] = auth_setting["value"]
                elif auth_setting["in"] == "query":
                    querys.append((auth_setting["key"], auth_setting["value"]))
                else:
                    raise ValueError(
                        "Authentication token must be in `query` or `header`"
                    )

    def __deserialize_file(self, response):
        """Deserializes body to file

        Saves response body into a file in a temporary folder,
        using the filename from the `Content-Disposition` header if provided.

        :param response:  RESTResponse.
        :return: file path.
        """
        fd, path = tempfile.mkstemp(dir=self.configuration.temp_folder_path)
        os.close(fd)
        os.remove(path)

        content_disposition = response.getheader("Content-Disposition")
        if content_disposition:
            filename = re.search(
                r'filename=[\'"]?([^\'"\s]+)[\'"]?', content_disposition
            ).group(1)
            path = os.path.join(os.path.dirname(path), filename)
            response_data = response.data
            with open(path, "wb") as f:
                if isinstance(response_data, str):
                    # change str to bytes so we can write it
                    response_data = response_data.encode("utf-8")
                    f.write(response_data)
                else:
                    f.write(response_data)
        return path

    def __deserialize_primitive(self, data, klass):
        """Deserializes string to primitive type.

        :param data: str.
        :param klass: class literal.

        :return: int, long, float, str, bool.
        """
        try:
            return klass(data)
        except UnicodeEncodeError:
            return str
        except TypeError:
            return data

    def __deserialize_object(self, value):
        """Return a original value.

        :return: object.
        """
        return value

    def __deserialize_date(self, string):
        """Deserializes string to date.

        :param string: str.
        :return: date.
        """
        try:
            from dateutil.parser import parse

            return parse(string).date()
        except ImportError:
            return string
        except ValueError:
            raise SerializationError(f"Failed to parse `{string}` as date object")

    def __deserialize_datatime(self, string):
        """Deserializes string to datetime.

        The string should be in iso8601 datetime format.

        :param string: str.
        :return: datetime.
        """
        try:
            from dateutil.parser import parse

            return parse(string)
        except ImportError:
            return string
        except ValueError:
            raise SerializationError(f"Failed to parse `{string}` as datetime object")

    def __hasattr(self, object, name):
        return name in object.__class__.__dict__

    def __deserialize_model(self, data, klass):
        """Deserializes list or dict to model.

        :param data: dict, list.
        :param klass: class literal.
        :return: model object.
        """

        if not klass.swagger_types and not self.__hasattr(
            klass, "get_real_child_model"
        ):
            return data

        kwargs = {}
        if klass.swagger_types is not None:
            for attr, attr_type in klass.swagger_types.items():
                if (
                    data is not None
                    and klass.attribute_map[attr] in data
                    and isinstance(data, (list, dict))
                ):
                    value = data[klass.attribute_map[attr]]
                    kwargs[attr] = self.deserialize(value, attr_type)

        instance = klass(**kwargs)

        if (
            isinstance(instance, dict)
            and klass.swagger_types is not None
            and isinstance(data, dict)
        ):
            for key, value in data.items():
                if key not in klass.swagger_types:
                    instance[key] = value
        if self.__hasattr(instance, "get_real_child_model"):
            klass_name = instance.get_real_child_model(data)
            if klass_name:
                instance = self.deserialize(data, klass_name)
        return instance


"""
Serialization usage

        # header parameters
        header_params = self.sanitize_for_serialization(header_params)
        header_params = dict(self.parameters_to_tuples(header_params,
                                                       collection_formats))

        # path parameters
        path_params = self.sanitize_for_serialization(path_params)
        path_params = self.parameters_to_tuples(path_params,
                                                collection_formats)
        for k, v in path_params:
            # specified safe chars, encode everything
            resource_path = resource_path.replace(
                '{%s}' % k,
                quote(str(v), safe=config.safe_chars_for_path_param)
            )

        # query parameters
        query_params = self.sanitize_for_serialization(query_params)
        query_params = self.parameters_to_tuples(query_params,
                                                 collection_formats)

        # post parameters
        post_params = self.prepare_post_parameters(post_params, files)
        post_params = self.sanitize_for_serialization(post_params)
        post_params = self.parameters_to_tuples(post_params,
                                                collection_formats)
"""
